title

# XMLRésuméLibrary: User Guide

tail | Element Reference | to

## Name

title — A title or heading

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `title` element contains a title or heading. Its semantics vary depending on the element that contains it:

`name`

  When contained in this element, `title` contains a person's formal title, such as “Dr.”, “Ms.”, or “Professor”.

`interest`

  When contained in this element, `title` contains the name of an interest, such as “Cooking”, or “Politics”.

`membership`, `referee`

  When contained in these elements, `title` contains the name of the person's role or capacity withing an organization. Examples: “Treasurer”, “Member”, “Chief Officer of Toothpaste Policy”, “Lead Programmer”.

`awards`, `interests`, `memberships`, `skillarea`

  When contained in these elements, `title` contains a heading for that section of a résumé. It is formatted as a top-level heading.

  ### Note

  The `title` element is optional in `awards` and `interests`. If it is not present, the `awards.word` and `interests.word` parameters will be used as the heading text in formatted résumés, respectively.

`skillset`

  When contained in this element, `title` contains the name of a skill category. Examples: “Teaching”, “Computers”, “Woodworking”, “Soap Carving”.

`subject`

  When contained in this element, `title` contains the name of a subject. It can be as general as “English” (a very broad field of study), or as specific as “Eng 115 Intro to Writing Fall 2001” (a specific university course name, number, and date of study).

### Parents

`title` may be contained in these elements: `award`, `awards`, `clearances`, `interest`, `interests`, `membership`, `memberships`, `name`, `referee`, `skillarea`, `skillset`, `subject`

## See Also

`artTitle`, `bookTitle`.

## Examples

Example 13. `interest` title

    <interest>
      <title>Fly fishing for sharks</title>
      <description><para>
        I once caught a 300-kg. Great White off the coase of Florida using a green
        and gold-colored dragonfly that I tied.
      </para></description>
    </interest>

Example 14. `membership` and `memberships` titles

    <memberships>
      <title>Professional Memberships</title>
      <membership>
        <organization>American Society of Blower-Uppers</organization>
      </membership>
      <membership>
        <title>Spokesperson</title>
        <organization>Smallville Demolitioneers</organization>
      </membership>
      <membership>
        <title>President</title>
        <organization>Willow County Pyrotechnicans' Guild</organization>
      </membership>
    </membership>

Example 15. `skillarea` and `skillset` titles

    <skillarea>
      <title>Computer Skills</title>
      <skillset>
        <title>Word Processing</title>
        <skill>Microsoft Word</skill>
        <skill>Corel WordPerfect</skill>
      </skillset>
      <skillset>
        <title>Programming</title>
        <skill>Perl</skill>
        <skill>Python</skill>
        <skill>XML</skill>
        <skill>C++</skill>
      </skillset>
    </skillarea>

Example 16. `subject` title

    <subject>
      <title>Intro to Sociology</title>
      <result>A-</result>
    </subject>

tail | Element Reference | to